@@ -11,8 +11,6 @@
 #include <iostream>
 using namespace std;
 
-#define CB_TEXT_BUILDER "%1 : %2"
-
 struct DialOutContext {
     CalloutInitiator *ci;
     DialCancelDlg *pDialDlg;
@@ -733,6 +731,11 @@ MainWindow::dialNow (const QString &strTarget)
 
     do // Begin cleanup block (not a loop)
     {
+        if (!bLoggedIn) {
+            setStatus ("User is not logged in yet. Cannot make any calls.");
+            break;
+        }
+
         QMutexLocker locker (&mtxDial);
         if (bCallInProgress) {
             setStatus ("Another call is in progress. Please try again later");
@@ -742,7 +745,7 @@ MainWindow::dialNow (const QString &strTarget)
         GVRegisteredNumber gvRegNumber;
         if (!getDialSettings (bDialout, gvRegNumber, ci))
         {
-            setStatus ("Unable to dial out because settings are not valid");
+            setStatus ("Unable to dial because settings are not valid.");
             break;
         }
 
@@ -786,6 +789,9 @@ MainWindow::dialNow (const QString &strTarget)
             }
         }
 
+        OsDependent &osd = Singletons::getRef().getOSD ();
+        osd.setLongWork (this, true);
+
         bCallInProgress = true;
         bDialCancelled = false;
 
@@ -858,7 +864,6 @@ MainWindow::dialAccessNumber (const QString  &strAccessNumber,
     }
 }//MainWindow::dialAccessNumber
 
-
 void
 MainWindow::dialComplete (bool bOk, const QVariantList &params)
 {
@@ -889,6 +894,9 @@ MainWindow::dialComplete (bool bOk, const QVariantList &params)
         setStatus (QString("Dial successful to %1.").arg(params[0].toString()));
     }
     bCallInProgress = false;
+
+    OsDependent &osd = Singletons::getRef().getOSD ();
+    osd.setLongWork (this, false);
 }//MainWindow::dialComplete
 
 void
@@ -1279,12 +1287,19 @@ MainWindow::onRegPhoneSelectionChange (int index)
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     dbMain.putCallback (QString("%1").arg (indRegPhone));
 
-    QDeclarativeContext *ctx = this->rootContext();
     RegNumData data;
     if (!modelRegNumber.getAt (indRegPhone, data)) {
         data.strName = "<Unknown>";
     }
-    ctx->setContextProperty ("currentPhoneName", data.strName);
+    QString disp = data.strName;
+    if (RNT_Callback == data.type) {
+        disp = "In : " + disp;
+    } else if (RNT_Callout == data.type) {
+        disp = "Out : " + disp;
+    }
+
+    QDeclarativeContext *ctx = this->rootContext();
+    ctx->setContextProperty ("currentPhoneName", disp);
 
     OsDependent &osd = Singletons::getRef().getOSD ();
     osd.setLongWork (this, false);
